@@ -1,4 +1,4 @@
-#' ggcoef - Plot Model Coefficients with broom and ggplot2
+#' Model coefficients with \pkg{broom} and \pkg{ggplot2}
 #'
 #' Plot the coefficients of a model with \pkg{broom} and \pkg{ggplot2}.
 #'
@@ -20,12 +20,15 @@
 #' @param errorbar_height height of the error bars
 #' @param errorbar_linetype line type of the error bars
 #' @param errorbar_size size of the error bars
-#' @param sort \code{"none"} (default) do not sort, \code{"ascending"} sort by increasing coefficient value, or \code{"decending"} sort by decreasing coefficient value
+#' @param sort \code{"none"} (default) do not sort, \code{"ascending"} sort by increasing coefficient value, or \code{"descending"} sort by decreasing coefficient value
 #' @param ... additional arguments sent to \code{\link[ggplot2]{geom_point}}
 #' @examples
+#' # Small function to display plots only if it's interactive
+#' p_ <- GGally::print_if_interactive
+#'
 #' library(broom)
 #' reg <- lm(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width, data = iris)
-#' ggcoef(reg)
+#' p_(ggcoef(reg))
 #' \donttest{d <- as.data.frame(Titanic)
 #' reg2 <- glm(Survived ~ Sex + Age + Class, family = binomial, data = d, weights = d$Freq)
 #' ggcoef(reg2, exponentiate = TRUE)
@@ -50,7 +53,7 @@ ggcoef <- function(
   errorbar_height = 0,
   errorbar_linetype = "solid",
   errorbar_size = .5,
-  sort = c("none", "ascending", "decending"),
+  sort = c("none", "ascending", "descending"),
   ...
 ) {
   if (!is.data.frame(x)) {
