@@ -1,9 +1,11 @@
-
 context("ggpairs")
+# This file takes too long
+testthat::skip_on_cran()
+
 data(tips, package = "reshape")
 
 expect_print <- function(p) {
-  testthat::expect_silent(print(p, progress = FALSE))
+  testthat::expect_silent(print(p))
 }
 
 facethistBindwidth1 <- list(combo = wrap("facethist", binwidth = 1))
@@ -215,14 +217,14 @@ test_that("stops", {
     ggduo(tips, types = c("not_a_list"))
   }, "'types' is not a list") # nolint
 
-  # couldn't get correct error message
-  #  variables: 'colour' have non standard format: 'total_bill + tip'.
-  expect_error({
-    ggpairs(tips, mapping = ggplot2::aes(color = total_bill + tip))
-  }, "variables\\: \"colour\" have non standard format") # nolint
-  expect_error({
-    ggduo(tips, mapping = ggplot2::aes(color = total_bill + tip))
-  }, "variables\\: \"colour\" have non standard format") # nolint
+  # # couldn't get correct error message
+  # #  variables: 'colour' have non standard format: 'total_bill + tip'.
+  # expect_error({
+  #   ggpairs(tips, mapping = ggplot2::aes(color = total_bill + tip))
+  # }, "variables\\: \"colour\" have non standard format") # nolint
+  # expect_error({
+  #   ggduo(tips, mapping = ggplot2::aes(color = total_bill + tip))
+  # }, "variables\\: \"colour\" have non standard format") # nolint
 
   errorString <- "'aes_string' is a deprecated element"
   expect_error({
@@ -353,7 +355,8 @@ test_that("axisLabels", {
       upper = "blank",
       lower = facethistBindwidth1,
       axisLabels = axisLabels,
-      title = str_c("axisLabels = ", axisLabels)
+      title = str_c("axisLabels = ", axisLabels),
+      progress = FALSE
     )
     pm
   }
@@ -361,6 +364,16 @@ test_that("axisLabels", {
     expect_obj(fn(axisLabels), axisLabels)
   }
 
+  plots <- ggpairs(iris, 1:3)$plots
+  for (val in c(TRUE, FALSE)) {
+    pm <- ggmatrix(
+      plots, 3, 3,
+      showAxisPlotLabels = val
+    )
+    expect_equal(pm$showXAxisPlotLabels, val)
+    expect_equal(pm$showYAxisPlotLabels, val)
+  }
+
 
   fn <- function(axisLabels) {
     a <- ggduo(
@@ -509,41 +522,46 @@ test_that("NA data", {
 
 })
 
-test_that("stip-top and strip-right", {
+test_that("strip-top and strip-right", {
 
 
   data(tips, package = "reshape")
 
   double_strips <- function(data, mapping, ...) {
-    dt <- count(data, as.character(c(mapping$x, mapping$y)))
+    dt <- count(data, c(mapping_string(mapping$x), mapping_string(mapping$y)))
     ggplot2::qplot(
       xmin = 0.25, xmax = 0.75,
       ymin = 1, ymax = freq,
       data = dt, geom = "rect"
     ) +
-      ggplot2::facet_grid(paste0(mapping$y, " ~ ", mapping$x)) +
+      ggplot2::facet_grid(paste0(mapping_string(mapping$y), " ~ ", mapping_string(mapping$x))) +
       ggplot2::scale_x_continuous(breaks = 0.5, labels = NULL)
   }
 
   pm <- ggpairs(
     tips, 3:6,
     lower = "blank", diag = "blank",
-    upper = list(discrete = double_strips)
+    upper = list(discrete = double_strips),
+    progress = FALSE
   )
-  pm
+  expect_print(pm)
   pm <- ggpairs(
     tips, 3:6,
     lower = "blank", diag = "blank",
     upper = list(discrete = double_strips),
-    showStrips = TRUE
+    showStrips = TRUE,
+    progress = FALSE
   )
-  pm
+  expect_print(pm)
 
 })
 
 
 test_that("subtypes", {
 
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("Hmisc")
+
 # list of the different plot types to check
 # continuous
 #    points
@@ -585,6 +603,7 @@ test_that("subtypes", {
       upper = types,
       lower = types,
       diag = diag,
+      progress = FALSE,
       ...
     ) + ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
   }
@@ -606,6 +625,7 @@ test_that("subtypes", {
           ", discrete = ", gn(types$discrete),
         ")", sep = ""),
       types = types,
+      progress = FALSE,
       ...
     ) + ggplot2::theme(plot.title = ggplot2::element_text(size = 9))
   }
@@ -615,18 +635,30 @@ test_that("subtypes", {
       theme(legend.position = "bottom")
   }
 
+
   # re ordered the subs so that density can have no binwidth param
-  conSubs <- list("density", "points", "smooth", "smooth_loess", "cor", "blank")
+  conSubs <- list(
+    "autopoint",
+    "density", "points", "smooth", "smooth_lm", "smooth_loess", "cor",
+    "blank")
   comSubs <- list(
+    "autopoint",
     "box", "dot", "box_no_facet", "dot_no_facet",
     wrap("facethist", binwidth = 1),
-    "facetdensity", wrap("denstrip", binwidth = 1),
+    "facetdensity",
+    "facetdensitystrip",
+    "summarise_by",
+    wrap("denstrip", binwidth = 1),
     "blank"
   )
-  disSubs <- list("ratio", "facetbar", "blank")
+  disSubs <- list(
+    "autopoint", "colbar", "count",
+    "cross", "crosstable", "facetbar",
+    "ratio", "rowbar", "table", "trends",
+    "blank")
 
-  conDiagSubs <- c("densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
-  disDiagSubs <- c("barDiag", "blankDiag")
+  conDiagSubs <- c("autopointDiag", "densityDiag", wrap("barDiag", binwidth = 1), "blankDiag")
+  disDiagSubs <- c("autopointDiag", "barDiag", "countDiag", "tableDiag", "blankDiag")
 
   # for (fn in list(ggpairs_fn1, ggpairs_fn2, ggduo_fn1, ggduo_fn2)) {
   for (fn_num in 1:4) {
@@ -652,18 +684,24 @@ test_that("subtypes", {
       #   )
       # ))
       #
-      pm <- fn(
-        types = list(
-          continuous = conSub,
-          combo = comSub,
-          discrete = disSub
-        ),
-        diag = list(
-          continuous = diagConSub,
-          discrete = diagDisSub
+      expect_silent({
+        pm <- fn(
+          types = list(
+            continuous = conSub,
+            combo = comSub,
+            discrete = disSub
+          ),
+          diag = list(
+            continuous = diagConSub,
+            discrete = diagDisSub
+          )
         )
-      )
-      expect_print(pm)
+      })
+
+      if (grepl("/Users/barret/", getwd(), fixed = TRUE)) {
+        # only if on personal machine, do viz test
+        expect_print(pm)
+      }
     }
   }
 
